@@ -210,6 +210,10 @@ sub locales_enabled(;$) {
     # khw cargo-culted the '?' in the pattern on the next line.
     return 0 if $Config{ccflags} =~ /\bD?NO_LOCALE\b/;
 
+    # If we can't load the POSIX XS module, we can't have locales even if they
+    # normally would be available
+    return 0 if ! defined &DynaLoader::boot_DynaLoader;
+
     if (! $Config{d_setlocale}) {
         return 0 if $Config{ccflags} =~ /\bD?NO_POSIX_2008_LOCALE\b/;
         return 0 unless $Config{d_newlocale};
@@ -336,7 +340,7 @@ sub find_locales ($;$) {
     _trylocale("C", $categories, \@Locale, $allow_incompatible);
     _trylocale("POSIX", $categories, \@Locale, $allow_incompatible);
 
-    if ($Config{d_has_C_UTF8} eq 'true') {
+    if ($Config{d_has_C_UTF8} && $Config{d_has_C_UTF8} eq 'true') {
         _trylocale("C.UTF-8", $categories, \@Locale, $allow_incompatible);
     }
 
@@ -417,9 +421,10 @@ sub find_locales ($;$) {
         }
 
         # The rest of the locales are in this file.
-        push @Data, <DATA>;
+        push @Data, <DATA>; close DATA;
 
         foreach my $line (@Data) {
+            chomp $line;
             my ($locale_name, $language_codes, $country_codes, $encodings) =
                 split /:/, $line;
             _my_diag(__FILE__ . ":" . __LINE__ . ": Unexpected syntax in '$line'")
@@ -565,6 +570,8 @@ sub find_utf8_turkic_locales (;$) {
 
     my @return;
 
+    return unless locales_enabled('LC_CTYPE');
+
     my $save_locale = setlocale(&POSIX::LC_CTYPE());
     foreach my $locale (find_utf8_ctype_locales(shift)) {
         use locale;
